Name - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# Name

A `betty.ancestry.name.Name` describes a name that can be translated, and has a date to indicate its usage.

## Fields

`date` (Datey)

  When this name was used.

`id` (`str`)

  The name’s own entity ID.

`locale` (optional `str`)

  The name’s locale as an IETF BCP 47 language tag.

`name` (`str`)

  The human-readable name.